@@ -2,6 +2,7 @@
  * dlfcn-win32
  * Copyright (c) 2007-2009 Ramiro Polla
  * Copyright (c) 2014      Tiancheng "Timothy" Gu
+ * Copyright (c) 2019      Pali Rohár <pali.rohar@gmail.com>
  *
  * dlfcn-win32 is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,6 +26,7 @@
 #endif
 #include <stdio.h>
 #include <string.h>
+#include <windows.h>
 #include "dlfcn.h"
 
 /* If these dlclose's fails, we don't care as the handles are going to be
@@ -71,12 +73,16 @@
 int main()
 {
     void *global;
+    void *library2;
     void *library;
     char *error;
     int (*function)( void );
+    int (*function2_from_library2)( void );
     size_t (*fwrite_local) ( const void *, size_t, size_t, FILE * );
+    size_t (*fputs_default) ( const char *, FILE * );
     int (*nonexistentfunction)( void );
     int ret;
+    HMODULE library3;
 
 #ifdef _DEBUG
     _CrtSetReportMode(_CRT_WARN, _CRTDBG_MODE_FILE);
@@ -87,6 +93,16 @@ int main()
     _CrtSetReportFile(_CRT_ASSERT, _CRTDBG_FILE_STDOUT);
 #endif
 
+    library2 = dlopen( "testdll2.dll", RTLD_GLOBAL );
+    if( !library2 )
+    {
+        error = dlerror( );
+        printf( "ERROR\tCould not open library2 globally: %s\n", error ? error : "" );
+        RETURN_ERROR; 
+    }
+    else
+        printf( "SUCCESS\tOpened library2 globally: %p\n", library2 );
+
     library = dlopen( "testdll.dll", RTLD_GLOBAL );
     if( !library )
     {
@@ -124,6 +140,22 @@ int main()
     fwrite_local(hello_world,sizeof(char),strlen(hello_world),stderr);
     fflush(stderr);
 
+    fputs_default = dlsym(RTLD_DEFAULT, "fputs");
+    if (!fputs_default)
+    {
+        error = dlerror();
+        printf("ERROR\tCould not get symbol from default handle: %s\n",
+            error ? error : "");
+        CLOSE_LIB;
+        CLOSE_GLOBAL;
+        RETURN_ERROR;
+    }
+    else
+        printf("SUCCESS\tGot symbol from default handle: %p\n", fputs_default);
+    char * hello_world_fputs = "Hello world from default fputs!\n";
+    fputs_default(hello_world_fputs, stderr);
+    fflush(stderr);
+
     function = dlsym( library, "function" );
     if( !function )
     {
@@ -139,6 +171,27 @@ int main()
 
     RUNFUNC;
 
+    function2_from_library2 = dlsym( library2, "function2" );
+    if( !function2_from_library2 )
+    {
+        error = dlerror( );
+        printf( "ERROR\tCould not get symbol from library2 handle: %s\n",
+                error ? error : "" );
+        CLOSE_LIB;
+        CLOSE_GLOBAL;
+        RETURN_ERROR;
+    }
+    else
+        printf( "SUCCESS\tGot symbol from library2 handle: %p\n", function2_from_library2 );
+
+    ret = function2_from_library2 ();
+    if( ret != 2 )
+    {
+        CLOSE_LIB;
+        CLOSE_GLOBAL;
+        RETURN_ERROR;
+    }
+
     nonexistentfunction = dlsym( library, "nonexistentfunction" );
     if( nonexistentfunction )
     {
@@ -194,6 +247,16 @@ int main()
     else
         printf( "SUCCESS\tClosed library.\n" );
 
+    ret = dlclose( library2 );
+    if( ret )
+    {
+        error = dlerror( );
+        printf( "ERROR\tCould not close library2: %s\n", error ? error : "" );
+        RETURN_ERROR;
+    }
+    else
+        printf( "SUCCESS\tClosed library2.\n" );
+
     library = dlopen( "testdll.dll", RTLD_LOCAL );
     if( !library )
     {
@@ -335,6 +398,15 @@ int main()
         printf("SUCCESS\tGot symbol from global handle: %p\n", function);
     
 
+    library3 = LoadLibraryA("testdll3.dll");
+    if (!library3)
+    {
+        printf( "ERROR\tCould not open library3 via WINAPI\n" );
+        RETURN_ERROR;
+    }
+    else
+        printf( "SUCCESS\tOpened library3 via WINAPI: %p\n", library3 );
+
     ret = dlclose( library );
     if( ret )
     {
@@ -346,6 +418,21 @@ int main()
     else
         printf( "SUCCESS\tClosed library.\n" );
 
+    function = dlsym(global, "function3");
+    if (!function)
+    {
+        error = dlerror();
+        printf("ERROR\tCould not get symbol from global handle: %s\n",
+            error ? error : "");
+        CLOSE_LIB;
+        CLOSE_GLOBAL;
+        RETURN_ERROR;
+    }
+    else
+        printf("SUCCESS\tGot symbol from global handle: %p\n", function);
+
+    RUNFUNC;
+
     ret = dlclose( global );
     if( ret )
     {
